@@ -25,6 +25,9 @@ import type {
   ApiPermissionType, PermissionType,
   ApiEventType, EventType,
   ApiRoleType, RoleType,
+  ApiUserType, UserType,
+  UserOptionType,
+  RemoteUserOptionsType,
 } from './types'
 
 import { isWindows } from '_/helpers'
@@ -154,6 +157,7 @@ const VM = {
       },
       disks: [],
       consoles: [],
+      defaultConsole: 'undefined',
       snapshots: [],
       pool: {
         id: vm['vm_pool'] ? vm.vm_pool['id'] : undefined,
@@ -299,13 +303,14 @@ const VM = {
 //
 //
 const VmStatistics = {
-  toInternal ({ statistics }: { statistics: Array<ApiVmStatisticType> }): VmStatisticsType {
+  toInternal ({ statistics = [] }: { statistics: Array<ApiVmStatisticType> } = {}): VmStatisticsType {
     const base: VmStatisticsType = {
       memory: {},
       cpu: {},
       network: {},
       elapsedUptime: {
-        datum: 0,
+        firstDatum: undefined,
+        datum: [ 0 ],
         unit: 'seconds',
         description: 'Elapsed VM runtime (default to 0)',
       },
@@ -314,22 +319,28 @@ const VmStatistics = {
 
     for (const stat: ApiVmStatisticType of statistics) {
       if (stat.name === 'elapsed.time') {
-        base.elapsedUptime.datum = stat.values.value[0].datum
+        base.elapsedUptime.datum = stat.values.value.map((val: any) => val.datum)
+        base.elapsedUptime.firstDatum = base.elapsedUptime.datum[0]
         base.elapsedUptime.description = stat.description
       }
 
       if (stat.kind !== 'gauge') continue
 
-      // no values -> undefined, 1 value -> value.datum, >1 values -> [...values.datum]
-      // ?disks.usage -> {detail...}
-      let datum: any =
-        stat.values &&
-        stat.values.value &&
-        (stat.name === 'disks.usage'
-          ? stat.values.value[0] && stat.values.value[0].detail
-          : stat.values.value.length === 1
-            ? stat.values.value[0].datum
-            : stat.values.value.map(value => value.datum))
+      // no values -> undefined, >0 value -> [...values.datum]
+      let datum: any
+      if (stat.values && stat.values.value) {
+        if (stat.type === 'decimal' || stat.type === 'integer') {
+          datum = Array.isArray(stat.values.value)
+            ? stat.values.value.map((val: any) => val.datum)
+            : [stat.values.value.datum]
+        }
+
+        if (stat.type === 'string') {
+          datum = Array.isArray(stat.values.value)
+            ? stat.values.value.map((val: any) => val.detail)
+            : [stat.values.value.detail]
+        }
+      }
 
       if (stat.name === 'disks.usage' && !!datum) {
         datum = JSON.parse(datum)
@@ -339,9 +350,16 @@ const VmStatistics = {
           return data
         })
       }
+
+      const firstDatum: any =
+        (datum && datum.length > 0)
+          ? datum[0]
+          : undefined
+
       const nameParts = /^(memory|cpu|network|disks)\.(.*)?$/.exec(stat.name)
       if (nameParts) {
         base[nameParts[1]][nameParts[2]] = {
+          firstDatum,
           datum,
           unit: stat.unit,
           description: stat.description,
@@ -949,6 +967,63 @@ const Event = {
   toApi: undefined,
 }
 
+const RemoteUserOptions = {
+  toInternal: (options: Array<UserOptionType<string> & {name: string}> = []): RemoteUserOptionsType => {
+    const vmPortalOptions: Array<[string, UserOptionType<any>]> = options
+      .map(option => RemoteUserOption.toInternal(option))
+      // non-vmPortal props were reduced to undefined
+      // filter them out
+      .filter(Boolean)
+
+    const fromEntries = {}
+    vmPortalOptions.forEach(([name, option]) => { fromEntries[name] = option })
+
+    // pick only options supported by this version of the UI
+    const { locale } = fromEntries
+
+    return {
+      locale,
+    }
+  },
+}
+
+const VM_PORTAL_PREFIX = 'vmPortal.'
+
+const RemoteUserOption = {
+  canTransformToInternal: (name: string): boolean => !!name && name.startsWith(VM_PORTAL_PREFIX),
+  toInternal: ({ name, content, id }: UserOptionType<string> & {name: string} = {}): ?[string, UserOptionType<any>] => {
+    if (!RemoteUserOption.canTransformToInternal(name)) {
+      return undefined
+    }
+    return [
+      name.replace(VM_PORTAL_PREFIX, ''),
+      {
+        id,
+        content: JSON.parse(content),
+      }]
+  },
+  toApi: (name: string, option: UserOptionType<Object>): UserOptionType<string> & {name: string} => {
+    return ({
+      name: `${VM_PORTAL_PREFIX}${name}`,
+      // double encoding - value is transferred as a string
+      content: JSON.stringify(option.content),
+    })
+  },
+}
+
+const User = {
+  toInternal ({ user: { user_name: userName, last_name: lastName, email, principal } = {} }: { user: ApiUserType }): UserType {
+    return {
+      userName,
+      lastName,
+      email,
+      principal,
+    }
+  },
+
+  toApi: undefined,
+}
+
 //
 // Export each transforms individually so they can be consumed individually
 //
@@ -972,8 +1047,12 @@ export {
   Icon,
   VmConsoles,
   VmSessions,
+  VmStatistics,
   CloudInit,
   Permissions,
   Event,
   Role,
+  User,
+  RemoteUserOptions,
+  RemoteUserOption,
 }
