@@ -29,6 +29,7 @@ import {
   vmActionInProgress,
 
   getSingleVm,
+  setUser,
   setVmSnapshots,
 
   setUserMessages,
@@ -44,6 +45,7 @@ import {
   removeActiveRequest,
   getVmCdRom,
   setVmsFilters,
+  setVmConsoles,
 } from '_/actions'
 
 import {
@@ -81,12 +83,16 @@ import {
   GET_CONSOLE_OPTIONS,
   GET_POOLS,
   GET_RDP_VM,
+  GET_USER,
   GET_VMS,
   SAVE_CONSOLE_OPTIONS,
   SAVE_FILTERS,
   SELECT_POOL_DETAIL,
   SELECT_VM_DETAIL,
   NAVIGATE_TO_VM_DETAILS,
+  FETCH_CONSOLES,
+  NO_DEFAULT_CONSOLE,
+  EMPTY_CONSOLES_LIST,
 } from '_/constants'
 
 import {
@@ -109,9 +115,7 @@ const VM_FETCH_ADDITIONAL_DEEP = [
   'statistics',
 ]
 
-const VM_FETCH_ADDITIONAL_SHALLOW = [
-  'graphics_consoles',
-]
+const VM_FETCH_ADDITIONAL_SHALLOW = []
 
 export const EVERYONE_GROUP_ID = 'eee00000-0000-0000-0000-123456789eee'
 
@@ -183,6 +187,28 @@ export function* fetchByPage () {
   }))
 }
 
+function* fetchConsoles ({ payload: { vm } }) {
+  const vmId = vm.get('id')
+  const apiConsoles = yield callExternalAction('consoles', Api.consoles, { payload: { vmId } })
+
+  // headless VM (no graphics_consoles defined) - API response is `{}`
+  if (Object.values(apiConsoles).length === 0) {
+    yield put(setVmConsoles({ vmId, consolesList: [], selectedConsole: EMPTY_CONSOLES_LIST }))
+  }
+
+  if (apiConsoles && apiConsoles.graphics_console) {
+    const defaultConsoleProtocol = yield select(state => state.config.get('defaultConsole'))
+    const consoles = Transforms.VmConsoles.toInternal({ consoles: apiConsoles })
+    // select the console to use based on availability and app/user configs
+    const selectedConsole =
+      consoles.length === 0 ? EMPTY_CONSOLES_LIST
+        : consoles.length === 1 ? consoles[0]
+          : consoles.find(c => c.protocol === defaultConsoleProtocol) || NO_DEFAULT_CONSOLE
+
+    yield put(setVmConsoles({ vmId, consolesList: consoles, selectedConsole }))
+  }
+}
+
 export function* fetchVms ({ payload: { count, page, shallowFetch = true } }) {
   const fetchedVmIds = []
 
@@ -270,6 +296,17 @@ export function* fetchPools (action) {
   return fetchedPoolIds
 }
 
+export function* fetchCurrentUser () {
+  const userId = yield select((state) => state.config.getIn(['user', 'id']))
+  const user = yield callExternalAction('user', Api.user, {
+    payload: {
+      userId,
+    },
+  })
+
+  yield put(setUser({ user: Transforms.User.toInternal({ user }) }))
+}
+
 export function* fetchSinglePool (action) {
   const { poolId } = action.payload
 
@@ -552,6 +589,7 @@ export function* rootSaga () {
     throttle(100, GET_BY_PAGE, fetchByPage),
     throttle(100, GET_VMS, fetchVms),
     throttle(100, GET_POOLS, fetchPools),
+    takeLatest(GET_USER, fetchCurrentUser),
 
     takeLatest(GET_ALL_EVENTS, fetchAllEvents),
     takeEvery(DISMISS_EVENT, dismissEvent),
@@ -570,6 +608,7 @@ export function* rootSaga () {
     takeEvery(OPEN_CONSOLE_MODAL, openConsoleModal),
     takeEvery(DOWNLOAD_CONSOLE_VM, downloadVmConsole),
     takeEvery(GET_RDP_VM, getRDPVm),
+    takeEvery(FETCH_CONSOLES, fetchConsoles),
 
     takeEvery(SAVE_FILTERS, saveFilters),
 
