@@ -1,5 +1,5 @@
 import { getOsHumanName } from '../components/utils'
-import { enumMsg } from '_/intl'
+import { enumMsg, msg } from '_/intl'
 
 const getFieldValueMap = {
   name: (item) => item.get('name'),
@@ -10,17 +10,17 @@ const getFieldValueMap = {
 export const sortFields = [
   {
     id: 'name',
-    title: 'Name',
+    title: msg.name(),
     isNumeric: false,
   },
   {
     id: 'os',
-    title: 'Operating System',
+    title: msg.operatingSystem(),
     isNumeric: false,
   },
   {
     id: 'status',
-    title: 'Status',
+    title: msg.status(),
     isNumeric: false,
   },
 ]
